unit appsettings;

{ Time zone database files
  Firmware update files
  INI file
}

interface

{$ifdef fpc}
  {$mode delphi}{$H+}
{$endif}

uses
  Classes, SysUtils,  IniFiles;

type

 { TConfigurations }

 TConfigurations = class(TObject)
 public
   {other settings as fields here}
   constructor Create;
   destructor Destroy; override;
   procedure WriteString(Section:String=''; Key:String=''; KeyValue:String='');
   function ReadString(Section:String=''; Key:String=''; DefaultValue:String=''): String;
 end;


var
 vConfigurations: TConfigurations;
 ConfigFilePath, DataDirectory, FirmwareDirectory, TZDirectory, LogsDirectory: String;

implementation

{$IFDEF Win32}
uses
  //Windows, shlobj,
  SHFolder;
{$ENDIF}

{ TConfigurations }

constructor TConfigurations.Create;
{$ifdef Windows}
var
 ApplicationDataPath:Array[0..MaxPathLen] of Char; //Allocate memory
begin
  { Get the path which defaults to:
    \Documents and Settings\All Users\Application Data same as C:\ProgramData }

  SHGetFolderPath(0,CSIDL_COMMON_APPDATA,0,0,@ApplicationDataPath[0]);

  if DirectoryExists(ApplicationDataPath + '\Unihedron\') then
    begin
     DataDirectory:= ExpandFileName(ApplicationDataPath + '\Unihedron\');
    end
  else
    begin
       DataDirectory:= ExpandFileName('.\'); //This directory
    end;
  ConfigFilePath:=ExpandFileName(DataDirectory + 'udm.ini');
  LogsDirectory:= ExpandFileName(DataDirectory + 'logs' + DirectorySeparator);
{$endif}

{$ifdef Unix}
begin
 if DirectoryExists('/usr/share/udm') then
    DataDirectory:= '/usr/share/udm/' //Installed data directory
 else
    DataDirectory:= ExpandFileName('./'); //This directory

 ConfigFilePath := GetAppConfigFile(False); //personal configuration file
 LogsDirectory:= ExpandFileName(GetAppConfigDir(False));

 If Not DirectoryExists(LogsDirectory) then
   If Not CreateDir (LogsDirectory) Then
     Writeln ('Failed to create directory: '+LogsDirectory)
   else
     Writeln ('Created LogsDirectory: '+LogsDirectory);
{$endif}

if DirectoryExists(DataDirectory + 'firmware') then
  FirmwareDirectory:= ExpandFileName(DataDirectory + 'firmware' + DirectorySeparator)
else
  FirmwareDirectory:= ExpandFileName('.'+DirectorySeparator+'firmware' + DirectorySeparator);

 if DirectoryExists(DataDirectory + 'tzdatabase') then
   TZDirectory:= ExpandFileName(DataDirectory + 'tzdatabase' + DirectorySeparator)
 else
   TZDirectory:= ExpandFileName('.'+DirectorySeparator+'tzdatabase' + DirectorySeparator);

end;

destructor TConfigurations.Destroy;
begin
  WriteString();
  inherited Destroy;
end;

procedure TConfigurations.WriteString(Section:String=''; Key:String=''; KeyValue:String='');
var
  MyFile: TIniFile;
begin
  { Create file if it does not already exist. }
  MyFile := TIniFile.Create(ConfigFilePath);
  try
    { Write the information. }
    MyFile.WriteString(Section, Key, KeyValue);
  finally
    MyFile.Free;
  end;
end;

function TConfigurations.ReadString(Section:String=''; Key:String=''; DefaultValue:String=''): String;
var
  MyFile: TIniFile;
begin
  MyFile := TIniFile.Create(ConfigFilePath);
  try
    { Read the information. }
   Result := MyFile.ReadString(Section,Key,DefaultValue);
  finally
    MyFile.Free;
  end;
end;

initialization
  vConfigurations := TConfigurations.Create;
end.
